#! /bin/ksh
# 
# Copyright 2003 Sun Microsystems, Inc. All Rights Reserved.
# pragma ident @(#)es-setup.sh	1.64 05/01/25 Sun Microsystems
#

# This version of es-setup combines the functionality of the agent
# es-setup.sh script and server es-setup.sh script found in SunMC 3.0
# with new functionality to support:
#   a second agent package (SUNWeswha)
#   SunMC 4.0 Agent Update function
#   SunMC 4.0 GUI setup function

# usage: es-setup -AeG argument

#         where    A  = automatic (Agent Update) mode. es-setup does
#                     ask the user any questions, but gets canned responses
#                     from an input file.
#                  e  = exit if error during Agent Update.
#                  G = call from GUI setup 
#                          Argument = 0 , neither U5 or U10 system
#                                     5 , U5 system
#                                    10 , U10 system

# es-setup.sh logic is as follows:

#  1. If server package installed, define new systems using calls to es-device.
#  2. If agent package SUNWeswga is installed, this is a pre-Cheetah WGS system
#       Determine if U5 or U10 system. If so,
#          If automatic mode, get the system type (U5 or U10) from line 1 of
#          /var/opt/SUNWsymon/platform/platform.prop.
#          Else if GUI setup mode, get system type from input parameter.
#          Else ask the user to specify system type.
#          In all cases, rewrite the platform.prop file and store the system
#          type in line 1.
#       Create deviceinfo.conf file if N8200 or N8400 system.

#  3. If agent package SUNWeswha is installed, this is a Cheetah system. Build
#     deviceinfo.conf file for this system.

#  4. If either agent package is installed, preload the the config reader module
#     using the es-load-default tool.


AGENT_UPDATE=n		# No user interaction in this mode
GUI_CALL=n
EXIT_ON_ERROR=n

while getopts AeG: OPT
do
  case $OPT in

      A) AGENT_UPDATE=y
         ;;

      e) EXIT_ON_ERROR=y
         ;;

      G) GUI_CALL=y
         U5_10="$OPTARG"
         ;;
  esac
done

if [ -n "$AUTOCONFIG_RUNFILE" ]; then
	AGENT_UPDATE=y
fi


/usr/bin/pkginfo -qi SUNWescom
if [ $? -eq 0 ] ; then
   basedir=`/usr/bin/pkgparam SUNWescom BASEDIR`
else
   /usr/bin/pkginfo -qi SUNWeswga
   if [ $? -eq 0 ] ; then
      basedir=`/usr/bin/pkgparam SUNWeswga BASEDIR`
   fi
fi

if [ -z $"basedir" ]; then
    basedir=/opt
fi

ESWGS_SBIN=$basedir/SUNWsymon/addons/wgs/sbin

. "$basedir"/SUNWsymon/sbin/es-common.sh

set_basedir
PROGNAME="$0"; export PROGNAME
check_root
check_logfile setup
check_osver
set_xput
setup_textdomain ESWG_SCRIPTS

echolog  '----------------------------------------------------------'
echolog  '         Starting Sun Management Center WGS Setup         '
echolog  '----------------------------------------------------------'

#########################################################################
# ADD NEW PLATFORM FILES IF SunMC WGS Server 

/usr/bin/pkginfo -qi SUNWeswgs
if [ $? -eq 0 ] ; then

   $basedir/SUNWsymon/sbin/es-device -d $ESWGS_SBIN/WGS-ES_DEVICE.conf > /dev/null
   $basedir/SUNWsymon/sbin/es-device -a $ESWGS_SBIN/WGS-ES_DEVICE.conf > /dev/null
   
  # Add the RSC command using es-tool
  if [ ! -f $VARDIR/console-tools.cfg ]; then
	echo "# RSC Command" >> $VARDIR/console-tools.cfg
  fi

  /bin/grep -s "RSCLaunch" $VARDIR/console-tools.cfg > /dev/null
  if [ $? = 1 ]; then
      echo "com.sun.symon.base.modules.RSCLaunchProps:toolmenuname,com.sun.symon.base.modules.RSCLaunch" >> $VARDIR/console-tools.cfg
  fi
  
  $basedir/SUNWsymon/sbin/es-tool
fi

#########################################################################
# Check if either agent package installed

/usr/bin/pkginfo -qi SUNWeswga 
if [ $? -eq 0 ] ; then
   platform_list=`/usr/bin/pkgparam SUNWeswga ES_ADDON_PLATFORM`
else
   /usr/bin/pkginfo -qi SUNWeswha 
   if [ $? -eq 0 ] ; then
      platform_list=`/usr/bin/pkgparam SUNWeswha ES_ADDON_PLATFORM`
   else
      return 0      # Neither agent package installed.
   fi
fi

#########################################################################
# Shared agent setup code

if [ -f /usr/platform/sun4u/sbin/prtdiag ] ; then
    prtline=`/usr/platform/sun4u/sbin/prtdiag | head -1`
    if [ $? -ne 0 ] ] ; then
        echolog 'Unable to determine platform'
        return 1
    fi
else
    echolog 'Unable to determine platform'
    return 1
fi
 
if [ -z $"platform_list" ] ; then
  echolog 'Unable to determine package platform'
  return 1              # no platform list, return error
fi
 
if [ ! -f $VARDIR/base-modules-d.dat ] ; then
        /usr/bin/cp $BASEDIR/base/cfg/base-modules-d.dat $VARDIR/base-modules-d.dat
fi
 
 
# make dir if not there
mkdir -p ${PLATFORM_FILE%/*}

# Save line 1 of the platform.prop file if Agent Update mode

if [ $AGENT_UPDATE = y ]; then
   if [ -f $PLATFORM_FILE ] ; then
      /usr/bin/grep "UltraModel=5" "$PLATFORM_FILE" > /dev/null 2>& 1
      if [ $? -eq 0 ] ; then    
        saved_system_type=1    # implies U5
      else
        saved_system_type=2    # implies U10
      fi
   else
      saved_system_type=2      # assume U10 if file doesn't exist.
   fi
fi

touch "$PLATFORM_FILE"
rm "$PLATFORM_FILE"
touch "$PLATFORM_FILE"
 
deviceinfo="$VARDIR"/deviceinfo.conf
 
OIFS=$IFS
IFS=:,

#########################################################################
# Check if legacy WGS agent setup

/usr/bin/pkginfo -qi SUNWeswga
if [ $? -eq 0 ] ; then

# see if current platform is supported by WGS agent pkg.
for i in $platform_list;do
  echo "$prtline" | /usr/bin/grep "$i" > /dev/null 2>&1
  if [ $? -eq 0 ] ; then        # match
    echolog 'Platform Found\\: $i'

# *****************************************
 
    if [ $i = "StorEdge(TM) N8200 filer" ] ; then
      if [ -f $deviceinfo ] ; then
        rm $deviceinfo
      fi
      touch $deviceinfo
      cat << END_OF_INPUT > $deviceinfo
DID Enterprise-220R
OID 1.3.6.1.4.1.42.2.12.3.2.4
FAMILYTYPE sun4u-Sun-Enterprise-220R
END_OF_INPUT
    fi
 
# *****************************************
 
    if [ $i = "StorEdge(TM) N8400 filer" ] ; then
      if [ -f $deviceinfo ] ; then
        rm $deviceinfo
      fi
      touch $deviceinfo
      cat << END_OF_INPUT > $deviceinfo
DID Enterprise-420R
OID 1.3.6.1.4.1.42.2.12.3.2.5
FAMILYTYPE sun4u-Sun-Enterprise-420R
END_OF_INPUT
    fi

################################################################################
	if [ $i = "Enterprise 450" ] ; then
		if [ -f $deviceinfo ] ; then
			rm $deviceinfo
		fi
		touch $deviceinfo
		cat << END_OF_INPUT > $deviceinfo
DID Sun-Enterprise-450
OID 1.3.6.1.4.1.42.2.12.3.2.3
FAMILYTYPE sun4u-Ultra-Enterprise-450
END_OF_INPUT
	fi

################################################################################

	if [ $i = "Ultra 450" ] ; then
		if [ -f $deviceinfo ] ; then
			rm $deviceinfo
		fi
		touch $deviceinfo
		cat << END_OF_INPUT > $deviceinfo
DID Sun-Enterprise-450
OID 1.3.6.1.4.1.42.2.12.3.2.3
FAMILYTYPE sun4u-Ultra-Enterprise-450
END_OF_INPUT
	fi

################################################################################

	if [ $i = "Ultra 2" ] ; then
		if [ -f $deviceinfo ] ; then
			rm $deviceinfo
		fi
		touch $deviceinfo
		cat << END_OF_INPUT > $deviceinfo
DID Sun-Ultra-Enterprise-2
OID 1.3.6.1.4.1.42.2.12.3.1.2
FAMILYTYPE sun4u-Ultra-Enterprise-2
END_OF_INPUT
	fi

################################################################################


		if [ $i = "Ultra 5/10" ] ; then
################################################################################
			if [ -f $deviceinfo ] ; then
				rm $deviceinfo
			fi
			touch $deviceinfo
			cat << END_OF_INPUT > $deviceinfo
DID Sun-Ultra-Enterprise-5,10
OID 1.3.6.1.4.1.42.2.12.3.1.3
FAMILYTYPE sun4u-Sun-Ultra-Enterprise-5,10
END_OF_INPUT
################################################################################
			question="Enter the platform type [1\\\|2]: "
			answer=""
			while [ "$answer" = "" ]
			do

				if [ $GUI_CALL = "y" ] ; then
					if [ $U5_10 = "5" ] ; then
						answer=1
					else
						answer=2
					fi
				elif [ $AGENT_UPDATE = "y" ] ; then
					answer=$saved_system_type
				else

					echolog 'Choose the platform you are installing the agent on:'
					echolog '1.  Ultra 5'
					echolog '2.  Ultra 10'
					if [ "$LOGFILE" != "" ] ; then
						eval echo `gettext "$question"` " \\\c" >> "$LOGFILE"
					fi
					eval echo `gettext "$question"` " \\\c"
					read answer
					if [ "$LOGFILE" != "" ] ; then
						echo "$answer" >> "$LOGFILE"
					fi
				fi

				case "$answer" in
					1) echo "UltraModel=5" >> "$PLATFORM_FILE"
					break ;;
					2) echo "UltraModel=10" >> "$PLATFORM_FILE"
					break ;;
					*) answer=""
				esac
			done
		fi

		# See if entry is already there
		/usr/bin/grep WGSETUP "$PLATFORM_FILE" > /dev/null 2>& 1
    if [ $? -eq 1 ] ; then    # WGSSETUP not there yet, add it
        echo "WGSETUP" >> "$PLATFORM_FILE"
    fi

   "$basedir"/SUNWsymon/sbin/es-load-default -a -f "$basedir"/SUNWsymon/addons/wgs/sbin/Config-Reader4uwg.minfo > /dev/null 2>& 1

    # Done, platform was matched and either setup or not
    IFS=$OIFS
    return 0
  fi  # end match
done  # end for platform_list
IFS=$OIFS

fi
 
#########################################################################
# Check if newer WGS agent setup

/usr/bin/pkginfo -qi SUNWeswha
if [ $? -eq 0 ] ; then

# see if current platform is supported by WGS agent pkg.
for i in $platform_list;do
  echo "$prtline" | /usr/bin/grep "$i" > /dev/null 2>&1
  if [ $? -eq 0 ] ; then        # match
    echolog 'Platform Found\\: $i'
  NEW_MODEL=NO

    #
    # Build deviceinfo.conf file and stop/start picld for newer platforms
 

    if [ $i = "Sun Fire 280R" ] ; then
      NEW_MODEL=280R
      M=280r
      SUBOID=6
    fi
 
    if [ $i = "Sun Fire 880" ]  ||  [ $i = "Sun Fire V880" ] ; then
      NEW_MODEL=880
      M=880
      SUBOID=7
    fi
 
    if [ $i = "Sun Fire 480R" ] || [ $i = "Sun Fire V480" ] ; then
      NEW_MODEL=480R
      M=480r
      SUBOID=8
    fi

    if [ $i = "Sun Fire V890" ] ; then
      NEW_MODEL=V890
      M=v890
      SUBOID=9
    fi

    if [ $i = "Sun Fire V490" ] ; then
      NEW_MODEL=V490
      M=v490
      SUBOID=10
    fi

    if [ $NEW_MODEL != "NO" ] ; then
 
      if [ -f $deviceinfo ] ; then
        rm $deviceinfo
      fi
       
      touch $deviceinfo
 
      cat << END_OF_INPUT > $deviceinfo
DID Sun-Fire-$NEW_MODEL
OID 1.3.6.1.4.1.42.2.12.3.2.$SUBOID
FAMILYTYPE sun4u-Sun-Fire-$NEW_MODEL-vh
END_OF_INPUT
 
      A=SUNW,Sun-Fire-$NEW_MODEL
      RELEASE=`/usr/bin/uname -r | sed 's/^5/2/' | cut -d\. -f1,2`
         
      /bin/rm -f /usr/platform/sun4u/lib/sunmc_common.conf
      cp $basedir/SUNWsymon/lib/platform/cfg/sunmc_common.conf /usr/platform/sun4u/lib/sunmc_common.conf
 
      /bin/rm -f /usr/platform/"$A"/lib/picl/plugins/libsunmcplugin.so.1
      /bin/rm -f /usr/platform/"$A"/lib/picl/plugins/libsunmcplugin.so
 
      cp $basedir/SUNWsymon/base/lib/sparc-sun-solaris"$RELEASE"/libsunmcplugin.so.1 /usr/platform/"$A"/lib/picl/plugins/libsunmcplugin.so.1
 
      ln -s  /usr/platform/"$A"/lib/picl/plugins/libsunmcplugin.so.1  /usr/platform/"$A"/lib/picl/plugins/libsunmcplugin.so
 
      /bin/rm -f /usr/platform/"$A"/lib/libsunmc"$M"plugin.so.1
      /bin/rm -f /usr/platform/"$A"/lib/sunmcplugin.conf
 
      cp $basedir/SUNWsymon/lib/platform/cfg/"$A"/libsunmc"$M"plugin.so.1 /usr/platform/"$A"/lib/libsunmc"$M"plugin.so.1
 
      cp $basedir/SUNWsymon/lib/platform/cfg/"$A"/sunmcplugin.conf /usr/platform/"$A"/lib/sunmcplugin.conf
 
      /bin/rm -f /usr/platform/sun4u/lib/sunmc_common.conf
      cp $basedir/SUNWsymon/lib/platform/cfg/sunmc_common.conf /usr/platform/sun4u/lib

# Stop picld (twice if necessary) and then restart it, so it will recognize SunMC plugin.
 
      if [ $RELEASE != 2.10 ]; then 
          status=`ps -ef | grep picld | grep -v grep |  wc -l `
          if [ $status -ge 1 ]; then
             /etc/init.d/picld stop ; sleep 1       # stop it once.
             status=`ps -ef | grep picld | grep -v grep | wc -l `
             if [ $status -ge 1 ]; then
                /etc/init.d/picld stop              # stop it again if it still exists.
                sleep 1
             fi
          fi
          /etc/init.d/picld start
      else
          /usr/sbin/svcadm restart svc:/system/picl
      fi
 
    fi          # END OF NEW_MODEL BLOCK

    # See if entry is already there
    /usr/bin/grep WGSETUP "$PLATFORM_FILE" > /dev/null 2>& 1
    if [ $? -eq 1 ] ; then    # WGSSETUP not there yet, add it
        echo "WGSETUP" >> "$PLATFORM_FILE"
    fi

   "$basedir"/SUNWsymon/sbin/es-load-default -a -f "$basedir"/SUNWsymon/addons/wgs/sbin/Config-Reader4uvh.minfo > /dev/null 2>& 1

    # Done, platform was matched and either setup or not
    IFS=$OIFS
    return 0
  fi  # end match
done  # end for platform_list
IFS=$OIFS

fi

return 0

